@@ -14,7 +14,7 @@ gi.require_version('GtkSource', '3.0')
 gi.require_version('XApp', '1.0')
 from gi.repository import Gtk, Gdk, GtkSource, Gio, XApp
 
-from common import async, idle, InfoReportContainer, DATA_DIR, INFO_DIR
+from common import _async, idle, InfoReportContainer, DATA_DIR, INFO_DIR
 
 setproctitle.setproctitle("mintreport")
 
@@ -67,14 +67,14 @@ class MintReportWindow():
     def __init__(self, application):
 
         self.application = application
-        self.settings = Gio.Settings("com.linuxmint.report")
+        self.settings = Gio.Settings(schema_id="com.linuxmint.report")
 
         os.system("mkdir -p %s" % TMP_DIR)
         os.system("rm -rf %s/*" % TMP_DIR)
         os.system("mkdir -p %s" % UNPACK_DIR)
         os.system("cp -R %s/* %s/" % (DATA_DIR, TMP_DIR))
 
-        self.cache = apt.Cache()
+        self._cache = None
         # Set the Glade file
         gladefile = "/usr/share/linuxmint/mintreport/mintreport.ui"
         self.builder = Gtk.Builder()
@@ -135,8 +135,7 @@ class MintReportWindow():
         self.treeview_crashes.append_column(column)
         self.treeview_crashes.show()
         self.model_crashes = Gtk.ListStore(str, str, str, str, str, str, object) # timestamp, pid, exe, object
-        self.model_sort = self.model_crashes.sort_new_with_model()
-        self.model_sort.set_sort_func(COL_CRASH_DATE, sort_by_date)
+        self.model_crashes.set_sort_func(COL_CRASH_DATE, sort_by_date)
         self.treeview_crashes.set_model(self.model_crashes)
 
         self.buffer = GtkSource.Buffer()
@@ -196,18 +195,18 @@ class MintReportWindow():
         submenu = Gtk.Menu()
         menu.set_submenu(submenu)
 
-        item = Gtk.ImageMenuItem.new_with_label(_("Refresh"))
+        item = Gtk.ImageMenuItem(label=_("Refresh"))
         image = Gtk.Image.new_from_icon_name("view-refresh-symbolic", Gtk.IconSize.MENU)
         item.set_image(image)
         item.connect('activate', self.on_menu_refresh)
         key, mod = Gtk.accelerator_parse("<Control>R")
         item.add_accelerator("activate", accel_group, key, mod, Gtk.AccelFlags.VISIBLE)
         submenu.append(item)
-        item = Gtk.ImageMenuItem.new_with_label(_("Restore ignored reports"))
+        item = Gtk.ImageMenuItem(label=_("Restore ignored reports"))
         item.connect('activate', self.on_menu_restore)
         submenu.append(item)
         submenu.append(Gtk.SeparatorMenuItem())
-        item = Gtk.ImageMenuItem.new_with_label(_("Quit"))
+        item = Gtk.ImageMenuItem(label=_("Quit"))
         image = Gtk.Image.new_from_icon_name("application-exit-symbolic", Gtk.IconSize.MENU)
         item.set_image(image)
         item.connect('activate', self.on_menu_quit)
@@ -228,6 +227,16 @@ class MintReportWindow():
         item.connect("activate", self.open_about)
         submenu.append(item)
 
+    @property
+    def cache(self):
+        """Cache data from apt"""
+        if self._cache is None:
+            # Lazily initialize cache data because it is only used when a crash dump is selected
+            # on the 'Crash reports' page
+            self._cache = apt.Cache()
+
+        return self._cache
+
     def open_about(self, widget):
         dlg = Gtk.AboutDialog()
         dlg.set_transient_for(self.window)
@@ -267,7 +276,7 @@ class MintReportWindow():
     def on_menu_quit(self, widget):
         self.application.quit()
 
-    @async
+    @_async
     def load_sysinfo(self):
         try:
             sysinfo = subprocess.check_output("LANG=C inxi -Fxxrzc0 --usb", shell=True).decode("UTF-8")
@@ -330,7 +339,7 @@ class MintReportWindow():
             self.builder.get_object("box_info_stack").set_visible_child_name("done")
         self.builder.get_object("info_spinner").stop()
 
-    @async
+    @_async
     def load_info(self):
         self.loading = True
         self.clear_info_treeview()
@@ -366,20 +375,20 @@ class MintReportWindow():
             for child in self.info_descriptions_box.get_children():
                 self.info_descriptions_box.remove(child)
             for description in descriptions:
-                label = Gtk.Label(description)
+                label = Gtk.Label(label=description)
                 label.set_use_markup(True)
                 label.set_line_wrap(True)
                 self.info_descriptions_box.add(label)
             for child in self.info_button_box.get_children():
                 self.info_button_box.remove(child)
             for action in actions:
-                button = Gtk.Button(action.label)
+                button = Gtk.Button(label=action.label)
                 button.connect("clicked", self.on_info_action_clicked, action.callback, action.data)
                 if action.style is not None:
                     button.get_style_context().add_class(action.style)
                 self.info_button_box.add(button)
             if report.instance.has_ignore_button:
-                button = Gtk.Button(_("Ignore this problem"))
+                button = Gtk.Button(label=_("Ignore this report"))
                 button.connect("clicked", self.on_ignore_button_clicked)
                 self.info_button_box.add(button)
             self.builder.get_object("info_box").show_all()
@@ -395,8 +404,8 @@ class MintReportWindow():
             model, iter = self.treeview_info.get_selection().get_selected()
             if iter is not None:
                 report = model.get_value(iter, COL_INFO_REPORT)
-                dialog = Gtk.MessageDialog(self.window, 0, Gtk.MessageType.QUESTION, Gtk.ButtonsType.OK_CANCEL, _("Are you sure you want to ignore this problem?"))
-                dialog.format_secondary_text(_("The problem will be permanently ignored and will no longer be visible."))
+                dialog = Gtk.MessageDialog(self.window, 0, Gtk.MessageType.QUESTION, Gtk.ButtonsType.OK_CANCEL, _("Are you sure you want to ignore this report?"))
+                dialog.format_secondary_text(_("The report will be permanently ignored and will no longer be visible."))
                 response = dialog.run()
                 dialog.destroy()
                 if response == Gtk.ResponseType.OK:
@@ -459,7 +468,7 @@ class MintReportWindow():
             report = model.get_value(iter, COL_CRASH_OBJECT)
             self.dump_crash_report(report)
 
-    @async
+    @_async
     def dump_crash_report(self, report):
 
         os.chdir(UNPACK_DIR)
