@@ -69,7 +69,7 @@ class MyApplication(Gtk.Application):
 
     def on_statusicon_activated(self, icon, button, time):
         if button == Gdk.BUTTON_PRIMARY:
-            subprocess.Popen(["/bin/sh", "/usr/bin/mintreport"])
+            GLib.spawn_async(["/usr/bin/mintreport"])
             self.status_icon.set_visible(False)
 
     def on_gtk_statusicon_activated(self, status_icon):
@@ -79,7 +79,7 @@ class MyApplication(Gtk.Application):
         self.menu.popup(None, None, None, None, button, time)
 
     def on_menu_show(self, widget):
-        subprocess.Popen(["/bin/sh", "/usr/bin/mintreport"])
+        GLib.spawn_async(["/usr/bin/mintreport"])
 
     def on_menu_quit(self, widget):
         self.quit()
