@@ -3,6 +3,7 @@ import gi
 import os
 import subprocess
 import re
+import json
 
 gi.require_version('Gtk', '3.0')
 from gi.repository import Gtk
@@ -49,9 +50,20 @@ class Report(InfoReport):
     def is_pertinent(self):
         # Defines whether this report should show up
         self.drivers = []
+
+        # ubuntu-drivers and UbuntuDrivers module share the same package; if it's
+        # missing, we're on lmde.
+        if not os.path.exists("/usr/bin/ubuntu-drivers"):
+            return False
+
         try:
-            from UbuntuDrivers import detect
-            devices = detect.system_device_drivers()
+            output = subprocess.check_output(
+                ["python3",
+                 "-c",
+                 "import json; from UbuntuDrivers import detect; d = json.dumps(detect.system_device_drivers()); print(d)"],
+                stderr=subprocess.DEVNULL).decode("UTF-8")
+
+            devices = json.loads(output)
             for device_id in devices:
                 device = devices[device_id]
                 device_name = self.construct_name(device)
